@@ -78,6 +78,7 @@ File_Pcm::File_Pcm()
     //In
     Frame_Count_Valid=4;
     BitDepth=0;
+    BitDepth_Significant=0;
     Channels=0;
     SamplingRate=0;
     Endianness='\0';
@@ -212,7 +213,12 @@ void File_Pcm::Streams_Fill()
     Fill(Stream_Audio, 0, Audio_Codec_Settings_ITU, ITU);
 
     //BitDepth
-    if (BitDepth)
+    if (BitDepth_Significant)
+    {
+        Fill(Stream_Audio, 0, Audio_BitDepth, BitDepth_Significant);
+        Fill(Stream_Audio, 0, Audio_BitDepth_Stored, BitDepth);
+    }
+    else if (BitDepth)
         Fill(Stream_Audio, 0, Audio_BitDepth, BitDepth);
 
     //Channels
@@ -300,16 +306,12 @@ void File_Pcm::Data_Parse()
 {
     #if MEDIAINFO_DEMUX
         FrameInfo.PTS=FrameInfo.DTS;
-        int64u Frame_Count_NotParsedIncluded_ToAdd=0;
         if (Frame_Count_Valid_Demux)
         {
             if (FrameInfo.DUR!=(int64u)-1)
                 FrameInfo.DUR*=Frame_Count_Valid_Demux;
-            if (Frame_Count_NotParsedIncluded!=(int64u)-1 && Frame_Count_Valid_Demux-1<=Frame_Count_NotParsedIncluded)
-            {
-                Frame_Count_NotParsedIncluded_ToAdd=Frame_Count_Valid_Demux-1;
-                Frame_Count_NotParsedIncluded-=Frame_Count_NotParsedIncluded_ToAdd;
-            }
+            if (Frame_Count_NotParsedIncluded!=(int64u)-1 && Frame_Count_NotParsedIncluded>=Frame_Count_Valid_Demux)
+                Frame_Count_NotParsedIncluded-=Frame_Count_Valid_Demux-1;
         }
         Demux_random_access=true;
         Element_Code=(int64u)-1;
@@ -383,9 +385,11 @@ void File_Pcm::Data_Parse()
     if (Frame_Count_Valid_Demux)
     {
         Frame_Count+=Frame_Count_Valid_Demux-1;
-        if (Frame_Count_NotParsedIncluded!=(int64u)-1 && Frame_Count_NotParsedIncluded_ToAdd)
-            Frame_Count_NotParsedIncluded+=Frame_Count_NotParsedIncluded_ToAdd;
+        if (Frame_Count_NotParsedIncluded!=(int64u)-1)
+            Frame_Count_NotParsedIncluded+=Frame_Count_Valid_Demux-1;
         FrameInfo.DUR/=Frame_Count_Valid_Demux;
+        if (FrameInfo.DTS!=(int64u)-1)
+            FrameInfo.DTS+=FrameInfo.DUR*Frame_Count;
         Frame_Count_Valid_Demux=0;
     }
     #endif //MEDIAINFO_DEMUX
