@@ -1,21 +1,8 @@
-// File_Other - Use magic number to detect only the format
-// Copyright (C) 2002-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
 
 //---------------------------------------------------------------------------
 // Pre-compilation
@@ -51,7 +38,10 @@ void File_Other::Read_Buffer_Continue()
 {
     //Integrity
     if (Buffer_Size<16)
+    {
+        Element_WaitForMoreData();
         return;
+    }
 
     Ztring Format;
          if (CC4(Buffer)==0xC5C6CBC3) {Format=__T("RISC OS Chunk data");}
@@ -170,6 +160,7 @@ void File_Other::Read_Buffer_Continue()
         Finish("Shorten");
         return;
     }
+    else if (CC4(Buffer)==0x504C5646) {Format=__T("PlayLater Video");}
     else if (CC4(Buffer)==CC4("")) {Format=__T("");}
 
     if (Format.empty())
@@ -180,6 +171,7 @@ void File_Other::Read_Buffer_Continue()
 
     Accept();
 
+    Element_Offset=File_Size-(File_Offset+Buffer_Offset);
     Fill(Stream_General, 0, General_Format, Format);
 
     Finish();
