@@ -265,6 +265,12 @@ enum general
     General_Album_ReplayGain_Gain_String,
     General_Album_ReplayGain_Peak,
     General_Encryption,
+    General_Encryption_Format,
+    General_Encryption_Length,
+    General_Encryption_Method,
+    General_Encryption_Mode,
+    General_Encryption_Padding,
+    General_Encryption_InitializationVector,
     General_Title,
     General_Title_More,
     General_Title_Url,
@@ -473,7 +479,7 @@ enum video
     Video_Format_Settings_Pulldown,
     Video_Format_Settings_FrameMode,
     Video_Format_Settings_GOP,
-    Video_Format_Settings_FrameStructures,
+    Video_Format_Settings_PictureStructure,
     Video_Format_Settings_Wrapping,
     Video_InternetMediaType,
     Video_MuxingMode,
@@ -750,6 +756,7 @@ enum audio
     Audio_Format_Settings_Law,
     Audio_Format_Settings_ITU,
     Audio_Format_Settings_Wrapping,
+    Audio_Matrix_Format,
     Audio_InternetMediaType,
     Audio_MuxingMode,
     Audio_MuxingMode_MoreInfo,
@@ -821,9 +828,14 @@ enum audio
     Audio_Channel_s__String,
     Audio_Channel_s__Original,
     Audio_Channel_s__Original_String,
+    Audio_Matrix_Channel_s_,
+    Audio_Matrix_Channel_s__String,
     Audio_ChannelPositions,
     Audio_ChannelPositions_String2,
+    Audio_Matrix_ChannelPositions,
+    Audio_Matrix_ChannelPositions_String2,
     Audio_ChannelLayout,
+    Audio_ChannelLayoutID,
     Audio_SamplingRate,
     Audio_SamplingRate_String,
     Audio_SamplingCount,
@@ -836,6 +848,8 @@ enum audio
     Audio_Resolution_String,
     Audio_BitDepth,
     Audio_BitDepth_String,
+    Audio_BitDepth_Stored,
+    Audio_BitDepth_Stored_String,
     Audio_Compression_Mode,
     Audio_Compression_Mode_String,
     Audio_Compression_Ratio,
