@@ -245,6 +245,9 @@
 #if defined(MEDIAINFO_SCC_YES)
     #include "MediaInfo/Text/File_Scc.h"
 #endif
+#if defined(MEDIAINFO_PDF_YES)
+    #include "MediaInfo/Text/File_Pdf.h"
+#endif
 #if defined(MEDIAINFO_SUBRIP_YES)
     #include "MediaInfo/Text/File_SubRip.h"
 #endif
@@ -584,6 +587,9 @@ File__MultipleParsing::File__MultipleParsing()
     #if defined(MEDIAINFO_N19_YES)
         Parser.push_back(new File_N19());
     #endif
+    #if defined(MEDIAINFO_PDF_YES)
+        Parser.push_back(new File_Pdf());
+    #endif
     #if defined(MEDIAINFO_SCC_YES)
         Parser.push_back(new File_Scc());
     #endif
