@@ -292,7 +292,8 @@ void File_Dpx::Streams_Accept()
         TestContinuousFileNames();
 
         Stream_Prepare((Config->File_Names.size()>1 || Config->File_IsReferenced_Get())?Stream_Video:Stream_Image);
-        Fill(StreamKind_Last, StreamPos_Last, "StreamSize", File_Size);
+        if (File_Size!=(int64u)-1)
+            Fill(StreamKind_Last, StreamPos_Last, Fill_Parameter(StreamKind_Last, Generic_StreamSize), File_Size);
         if (StreamKind_Last==Stream_Video)
             Fill(Stream_Video, StreamPos_Last, Video_FrameCount, Config->File_Names.size());
     }
