@@ -22,9 +22,9 @@
 #if MEDIAINFO_EVENTS
     #include "ZenLib/FileName.h"
 #endif //MEDIAINFO_EVENTS
-#if MEDIAINFO_IBI
+#if MEDIAINFO_IBI || MEDIAINFO_AES
     #include "base64.h"
-#endif //MEDIAINFO_IBI
+#endif //MEDIAINFO_IBI || MEDIAINFO_AES
 #include <algorithm>
 #if MEDIAINFO_DEMUX
     #include <cmath>
@@ -73,6 +73,13 @@ MediaInfo_Config_MediaInfo::MediaInfo_Config_MediaInfo()
     #endif //defined(MEDIAINFO_REFERENCES_YES)
     File_TimeToLive=0;
     File_Buffer_Size_Hint_Pointer=NULL;
+    File_Buffer_Read_Size=64*1024*1024;
+    #if MEDIAINFO_AES
+        Encryption_Format=Encryption_Format_None;
+        Encryption_Method=Encryption_Method_None;
+        Encryption_Mode=Encryption_Mode_None;
+        Encryption_Padding=Encryption_Padding_None;
+    #endif //MEDIAINFO_AES
     #if MEDIAINFO_NEXTPACKET
         NextPacket=false;
     #endif //MEDIAINFO_NEXTPACKET
@@ -91,6 +98,7 @@ MediaInfo_Config_MediaInfo::MediaInfo_Config_MediaInfo()
         Demux_PCM_20bitTo16bit=false;
         Demux_PCM_20bitTo24bit=false;
         Demux_Avc_Transcode_Iso14496_15_to_Iso14496_10=false;
+        Demux_Hevc_Transcode_Iso14496_15_to_AnnexB=false;
         Demux_Unpacketize=false;
         Demux_Rate=0;
         Demux_FirstDts=(int64u)-1;
@@ -159,6 +167,9 @@ MediaInfo_Config_MediaInfo::MediaInfo_Config_MediaInfo()
            Demux_IsSeeking=false;
         #endif //MEDIAINFO_SEEK
     #endif //MEDIAINFO_DEMUX
+    #if MEDIAINFO_SEEK
+        File_GoTo_IsFrameOffset=false;
+    #endif //MEDIAINFO_SEEK
 }
 
 MediaInfo_Config_MediaInfo::~MediaInfo_Config_MediaInfo()
@@ -417,6 +428,15 @@ Ztring MediaInfo_Config_MediaInfo::Option (const String &Option, const String &V
     {
         return Ztring::ToZtring((size_t)File_Buffer_Size_Hint_Pointer_Get());
     }
+    else if (Option_Lower==__T("file_buffer_read_size"))
+    {
+        File_Buffer_Read_Size_Set((size_t)Ztring(Value).To_int64u());
+        return __T("");
+    }
+    else if (Option_Lower==__T("file_buffer_read_size_get"))
+    {
+        return Ztring::ToZtring((size_t)File_Buffer_Read_Size_Get());
+    }
     else if (Option_Lower==__T("file_filter"))
     {
         #if MEDIAINFO_FILTER
@@ -460,7 +480,7 @@ Ztring MediaInfo_Config_MediaInfo::Option (const String &Option, const String &V
     else if (Option_Lower==__T("file_demux_forceids"))
     {
         #if MEDIAINFO_DEMUX
-            if (Value.empty())
+            if (Ztring(Value).To_int64u()==0)
                 Demux_ForceIds_Set(false);
             else
                 Demux_ForceIds_Set(true);
@@ -472,7 +492,7 @@ Ztring MediaInfo_Config_MediaInfo::Option (const String &Option, const String &V
     else if (Option_Lower==__T("file_demux_pcm_20bitto16bit"))
     {
         #if MEDIAINFO_DEMUX
-            if (Value.empty())
+            if (Ztring(Value).To_int64u()==0)
                 Demux_PCM_20bitTo16bit_Set(false);
             else
                 Demux_PCM_20bitTo16bit_Set(true);
@@ -484,7 +504,7 @@ Ztring MediaInfo_Config_MediaInfo::Option (const String &Option, const String &V
     else if (Option_Lower==__T("file_demux_pcm_20bitto24bit"))
     {
         #if MEDIAINFO_DEMUX
-            if (Value.empty())
+            if (Ztring(Value).To_int64u()==0)
                 Demux_PCM_20bitTo24bit_Set(false);
             else
                 Demux_PCM_20bitTo24bit_Set(true);
@@ -496,7 +516,7 @@ Ztring MediaInfo_Config_MediaInfo::Option (const String &Option, const String &V
     else if (Option_Lower==__T("file_demux_avc_transcode_iso14496_15_to_iso14496_10"))
     {
         #if MEDIAINFO_DEMUX
-            if (Value.empty())
+            if (Ztring(Value).To_int64u()==0)
                 Demux_Avc_Transcode_Iso14496_15_to_Iso14496_10_Set(false);
             else
                 Demux_Avc_Transcode_Iso14496_15_to_Iso14496_10_Set(true);
@@ -505,10 +525,22 @@ Ztring MediaInfo_Config_MediaInfo::Option (const String &Option, const String &V
             return __T("Demux manager is disabled due to compilation options");
         #endif //MEDIAINFO_DEMUX
     }
+    else if (Option_Lower==__T("file_demux_hevc_transcode_iso14496_15_to_annexb"))
+    {
+        #if MEDIAINFO_DEMUX
+            if (Ztring(Value).To_int64u()==0)
+                Demux_Hevc_Transcode_Iso14496_15_to_AnnexB_Set(false);
+            else
+                Demux_Hevc_Transcode_Iso14496_15_to_AnnexB_Set(true);
+            return Ztring();
+        #else //MEDIAINFO_DEMUX
+            return __T("Demux manager is disabled due to compilation options");
+        #endif //MEDIAINFO_DEMUX
+    }
     else if (Option_Lower==__T("file_demux_unpacketize"))
     {
         #if MEDIAINFO_DEMUX
-            if (Value.empty())
+            if (Ztring(Value).To_int64u()==0)
                 Demux_Unpacketize_Set(false);
             else
                 Demux_Unpacketize_Set(true);
@@ -593,7 +625,7 @@ Ztring MediaInfo_Config_MediaInfo::Option (const String &Option, const String &V
     else if (Option_Lower==__T("file_ibi_create"))
     {
         #if MEDIAINFO_IBI
-            if (Value.empty())
+            if (Ztring(Value).To_int64u()==0)
                 Ibi_Create_Set(false);
             else
                 Ibi_Create_Set(true);
@@ -605,7 +637,7 @@ Ztring MediaInfo_Config_MediaInfo::Option (const String &Option, const String &V
     else if (Option_Lower==__T("file_ibi_useibiinfoifavailable"))
     {
         #if MEDIAINFO_IBI
-            if (Value.empty())
+            if (Ztring(Value).To_int64u()==0)
                 Ibi_UseIbiInfoIfAvailable_Set(false);
             else
                 Ibi_UseIbiInfoIfAvailable_Set(true);
@@ -614,10 +646,64 @@ Ztring MediaInfo_Config_MediaInfo::Option (const String &Option, const String &V
             return __T("IBI support is disabled due to compilation options");
         #endif //MEDIAINFO_IBI
     }
+    else if (Option_Lower==__T("file_encryption_format"))
+    {
+        #if MEDIAINFO_AES
+            Encryption_Format_Set(Value);
+            return Ztring();
+        #else //MEDIAINFO_AES
+            return __T("Encryption manager is disabled due to compilation options");
+        #endif //MEDIAINFO_AES
+    }
+    else if (Option_Lower==__T("file_encryption_key"))
+    {
+        #if MEDIAINFO_AES
+            Encryption_Key_Set(Value);
+            return Ztring();
+        #else //MEDIAINFO_AES
+            return __T("Encryption manager is disabled due to compilation options");
+        #endif //MEDIAINFO_AES
+    }
+    else if (Option_Lower==__T("file_encryption_method"))
+    {
+        #if MEDIAINFO_AES
+            Encryption_Method_Set(Value);
+            return Ztring();
+        #else //MEDIAINFO_AES
+            return __T("Encryption manager is disabled due to compilation options");
+        #endif //MEDIAINFO_AES
+    }
+    else if (Option_Lower==__T("file_encryption_mode") || Option_Lower==__T("file_encryption_modeofoperation"))
+    {
+        #if MEDIAINFO_AES
+            Encryption_Mode_Set(Value);
+            return Ztring();
+        #else //MEDIAINFO_AES
+            return __T("Encryption manager is disabled due to compilation options");
+        #endif //MEDIAINFO_AES
+    }
+    else if (Option_Lower==__T("file_encryption_padding"))
+    {
+        #if MEDIAINFO_AES
+            Encryption_Padding_Set(Value);
+            return Ztring();
+        #else //MEDIAINFO_AES
+            return __T("Encryption manager is disabled due to compilation options");
+        #endif //MEDIAINFO_AES
+    }
+    else if (Option_Lower==__T("file_encryption_initializationvector"))
+    {
+        #if MEDIAINFO_AES
+            Encryption_InitializationVector_Set(Value);
+            return Ztring();
+        #else //MEDIAINFO_AES
+            return __T("Encryption manager is disabled due to compilation options");
+        #endif //MEDIAINFO_AES
+    }
     else if (Option_Lower==__T("file_nextpacket"))
     {
         #if MEDIAINFO_NEXTPACKET
-            if (Value.empty())
+            if (Ztring(Value).To_int64u()==0)
                 NextPacket_Set(false);
             else
                 NextPacket_Set(true);
@@ -1259,14 +1345,6 @@ Ztring MediaInfo_Config_MediaInfo::File_ForceParser_Get ()
     return File_ForceParser;
 }
 
-//***************************************************************************
-/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
- *
- *  Use of this source code is governed by a BSD-style license that can
- *  be found in the License.html file in the root of the source tree.
- */
-//***************************************************************************
-
 //---------------------------------------------------------------------------
 void MediaInfo_Config_MediaInfo::File_Buffer_Size_Hint_Pointer_Set (size_t* NewValue)
 {
@@ -1280,6 +1358,19 @@ size_t*  MediaInfo_Config_MediaInfo::File_Buffer_Size_Hint_Pointer_Get ()
     return File_Buffer_Size_Hint_Pointer;
 }
 
+//---------------------------------------------------------------------------
+void MediaInfo_Config_MediaInfo::File_Buffer_Read_Size_Set (size_t NewValue)
+{
+    CriticalSectionLocker CSL(CS);
+    File_Buffer_Read_Size=NewValue;
+}
+
+size_t  MediaInfo_Config_MediaInfo::File_Buffer_Read_Size_Get ()
+{
+    CriticalSectionLocker CSL(CS);
+    return File_Buffer_Read_Size;
+}
+
 //***************************************************************************
 // Filter
 //***************************************************************************
@@ -1483,6 +1574,19 @@ bool MediaInfo_Config_MediaInfo::Demux_Avc_Transcode_Iso14496_15_to_Iso14496_10_
     return Demux_Avc_Transcode_Iso14496_15_to_Iso14496_10;
 }
 
+//---------------------------------------------------------------------------
+void MediaInfo_Config_MediaInfo::Demux_Hevc_Transcode_Iso14496_15_to_AnnexB_Set (bool NewValue)
+{
+    CriticalSectionLocker CSL(CS);
+    Demux_Hevc_Transcode_Iso14496_15_to_AnnexB=NewValue;
+}
+
+bool MediaInfo_Config_MediaInfo::Demux_Hevc_Transcode_Iso14496_15_to_AnnexB_Get ()
+{
+    CriticalSectionLocker CSL(CS);
+    return Demux_Hevc_Transcode_Iso14496_15_to_AnnexB;
+}
+
 //---------------------------------------------------------------------------
 void MediaInfo_Config_MediaInfo::Demux_Unpacketize_Set (bool NewValue)
 {
@@ -1604,6 +1708,203 @@ bool MediaInfo_Config_MediaInfo::Ibi_UseIbiInfoIfAvailable_Get ()
 }
 #endif //MEDIAINFO_IBI
 
+//***************************************************************************
+// Encryption
+//***************************************************************************
+
+//---------------------------------------------------------------------------
+#if MEDIAINFO_AES
+void MediaInfo_Config_MediaInfo::Encryption_Format_Set (const Ztring &Value)
+{
+    string Data=Value.To_UTF8();
+    encryption_format Encryption_Format_Temp=Encryption_Format_None;
+    if (Data=="AES")
+        Encryption_Format_Temp=Encryption_Format_Aes;
+
+    CriticalSectionLocker CSL(CS);
+    Encryption_Format=Encryption_Format_Temp;
+}
+
+//---------------------------------------------------------------------------
+void MediaInfo_Config_MediaInfo::Encryption_Format_Set (encryption_format Value)
+{
+    CriticalSectionLocker CSL(CS);
+    Encryption_Format=Value;
+}
+
+string MediaInfo_Config_MediaInfo::Encryption_Format_GetS ()
+{
+    CriticalSectionLocker CSL(CS);
+    switch (Encryption_Format)
+    {
+        case Encryption_Format_Aes: return "AES";
+        default: return string();
+    }
+}
+
+encryption_format MediaInfo_Config_MediaInfo::Encryption_Format_Get ()
+{
+    CriticalSectionLocker CSL(CS);
+    return Encryption_Format;
+}
+#endif //MEDIAINFO_AES
+
+//---------------------------------------------------------------------------
+#if MEDIAINFO_AES
+void MediaInfo_Config_MediaInfo::Encryption_Key_Set (const Ztring &Value)
+{
+    string Data_Base64=Value.To_UTF8();
+
+    CriticalSectionLocker CSL(CS);
+    Encryption_Key=Base64::decode(Data_Base64);
+}
+
+void MediaInfo_Config_MediaInfo::Encryption_Key_Set (const int8u* Value, size_t Value_Size)
+{
+    CriticalSectionLocker CSL(CS);
+    Encryption_Key=string((const char*)Value, Value_Size);
+}
+
+string MediaInfo_Config_MediaInfo::Encryption_Key_Get ()
+{
+    CriticalSectionLocker CSL(CS);
+    return Encryption_Key;
+}
+#endif //MEDIAINFO_AES
+
+//---------------------------------------------------------------------------
+#if MEDIAINFO_AES
+void MediaInfo_Config_MediaInfo::Encryption_Method_Set (const Ztring &Value)
+{
+    string Data=Value.To_UTF8();
+    encryption_method Encryption_Method_Temp=Encryption_Method_None;
+    if (Data=="Segment")
+        Encryption_Method_Temp=Encryption_Method_Segment;
+
+    CriticalSectionLocker CSL(CS);
+    Encryption_Method=Encryption_Method_Temp;
+}
+
+void MediaInfo_Config_MediaInfo::Encryption_Method_Set (encryption_method Value)
+{
+    CriticalSectionLocker CSL(CS);
+    Encryption_Method=Value;
+}
+
+string MediaInfo_Config_MediaInfo::Encryption_Method_GetS ()
+{
+    CriticalSectionLocker CSL(CS);
+    switch (Encryption_Method)
+    {
+        case Encryption_Method_Segment: return "Segment";
+        default: return string();
+    }
+}
+
+encryption_method MediaInfo_Config_MediaInfo::Encryption_Method_Get ()
+{
+    CriticalSectionLocker CSL(CS);
+    return Encryption_Method;
+}
+#endif //MEDIAINFO_AES
+
+//---------------------------------------------------------------------------
+#if MEDIAINFO_AES
+void MediaInfo_Config_MediaInfo::Encryption_Mode_Set (const Ztring &Value)
+{
+    string Data=Value.To_UTF8();
+    encryption_mode Encryption_Mode_Temp=Encryption_Mode_None;
+    if (Data=="CBC")
+        Encryption_Mode_Temp=Encryption_Mode_Cbc;
+
+    CriticalSectionLocker CSL(CS);
+    Encryption_Mode=Encryption_Mode_Temp;
+}
+
+void MediaInfo_Config_MediaInfo::Encryption_Mode_Set (encryption_mode Value)
+{
+    CriticalSectionLocker CSL(CS);
+    Encryption_Mode=Value;
+}
+
+string MediaInfo_Config_MediaInfo::Encryption_Mode_GetS ()
+{
+    CriticalSectionLocker CSL(CS);
+    switch (Encryption_Mode)
+    {
+        case Encryption_Mode_Cbc: return "CBC";
+        default: return string();
+    }
+}
+
+encryption_mode MediaInfo_Config_MediaInfo::Encryption_Mode_Get ()
+{
+    CriticalSectionLocker CSL(CS);
+    return Encryption_Mode;
+}
+#endif //MEDIAINFO_AES
+
+//---------------------------------------------------------------------------
+#if MEDIAINFO_AES
+void MediaInfo_Config_MediaInfo::Encryption_Padding_Set (const Ztring &Value)
+{
+    string Data=Value.To_UTF8();
+    encryption_padding Encryption_Padding_Temp=Encryption_Padding_None;
+    if (Data=="PKCS7")
+        Encryption_Padding_Temp=Encryption_Padding_Pkcs7;
+
+    CriticalSectionLocker CSL(CS);
+    Encryption_Padding=Encryption_Padding_Temp;
+}
+
+void MediaInfo_Config_MediaInfo::Encryption_Padding_Set (encryption_padding Value)
+{
+    CriticalSectionLocker CSL(CS);
+    Encryption_Padding=Value;
+}
+
+string MediaInfo_Config_MediaInfo::Encryption_Padding_GetS ()
+{
+    CriticalSectionLocker CSL(CS);
+    switch (Encryption_Padding)
+    {
+        case Encryption_Padding_Pkcs7: return "PKCS7";
+        default: return string();
+    }
+}
+
+encryption_padding MediaInfo_Config_MediaInfo::Encryption_Padding_Get ()
+{
+    CriticalSectionLocker CSL(CS);
+    return Encryption_Padding;
+}
+#endif //MEDIAINFO_AES
+
+//---------------------------------------------------------------------------
+#if MEDIAINFO_AES
+void MediaInfo_Config_MediaInfo::Encryption_InitializationVector_Set (const Ztring &Value)
+{
+    if (Value==__T("Sequence number"))
+    {
+        CriticalSectionLocker CSL(CS);
+        Encryption_InitializationVector="Sequence number";
+    }
+    else
+    {
+        string Data_Base64=Value.To_UTF8();
+
+        CriticalSectionLocker CSL(CS);
+        Encryption_InitializationVector=Base64::decode(Data_Base64);
+    }
+}
+
+string MediaInfo_Config_MediaInfo::Encryption_InitializationVector_Get ()
+{
+    CriticalSectionLocker CSL(CS);
+    return Encryption_InitializationVector;
+}
+#endif //MEDIAINFO_AES
+
 //***************************************************************************
 // NextPacket
 //***************************************************************************
