@@ -603,7 +603,7 @@ void MediaInfo_Internal::Entry()
                     #if MEDIAINFO_NEXTPACKET
                         if (Config.NextPacket_Get())
                             return;
-                   #endif //MEDIAINFO_NEXTPACKET
+                    #endif //MEDIAINFO_NEXTPACKET
                     Open_Buffer_Finalize();
                 }
             #else //defined(MEDIAINFO_REFERENCES_YES)
@@ -659,10 +659,11 @@ size_t MediaInfo_Internal::Open_Buffer_Init (int64u File_Size_, const String &Fi
 
     if (Info==NULL)
     {
-        if (!Config.File_ForceParser_Get().empty())
+        Ztring ForceParser = Config.File_ForceParser_Get();
+        if (!ForceParser.empty())
         {
             CS.Leave();
-            SelectFromExtension(Config.File_ForceParser_Get());
+            SelectFromExtension(ForceParser);
             CS.Enter();
         }
         if (Info==NULL)
@@ -682,14 +683,16 @@ size_t MediaInfo_Internal::Open_Buffer_Init (int64u File_Size_, const String &Fi
 
     #if MEDIAINFO_EVENTS
         {
+            string File_Name_Local=Ztring(File_Name).To_Local();
+            wstring File_Name_Unicode=Ztring(File_Name).To_Unicode();
             struct MediaInfo_Event_General_Start_0 Event;
             memset(&Event, 0xFF, sizeof(struct MediaInfo_Event_Generic));
             Event.EventCode=MediaInfo_EventCode_Create(MediaInfo_Parser_None, MediaInfo_Event_General_Start, 0);
             Event.EventSize=sizeof(struct MediaInfo_Event_General_Start_0);
             Event.StreamIDs_Size=0;
             Event.Stream_Size=File_Size_;
-            Event.FileName=NULL;
-            Event.FileName_Unicode=File_Name.c_str();
+            Event.FileName=File_Name_Local.c_str();
+            Event.FileName_Unicode=File_Name_Unicode.c_str();
             Config.Event_Send(NULL, (const int8u*)&Event, sizeof(MediaInfo_Event_General_Start_0));
         }
     #endif //MEDIAINFO_EVENTS
@@ -755,6 +758,18 @@ size_t MediaInfo_Internal::Open_Buffer_Init (int64u File_Size_, int64u File_Offs
     EXECUTE_SIZE_T(1, Debug+=__T("Open_Buffer_Init, will return 1");)
 }
 
+//---------------------------------------------------------------------------
+#if MEDIAINFO_ADVANCED2
+size_t MediaInfo_Internal::Open_Buffer_SegmentChange ()
+{
+    MEDIAINFO_DEBUG_CONFIG_TEXT(Debug+=__T("Open_Buffer_SegmentChange"))
+
+    Info->Open_Buffer_SegmentChange();
+
+    return 1;
+}
+#endif //MEDIAINFO_ADVANCED2
+
 //---------------------------------------------------------------------------
 void MediaInfo_Internal::Open_Buffer_Unsynch ()
 {
