@@ -440,12 +440,15 @@ void File_Gxf::Streams_Finish_PerStream(size_t StreamID, stream &Temp)
                 Merge(*Temp.Parsers[0], Stream_Video, 0, StreamPos_Last);
                 Fill(Stream_Video, StreamPos_Last, Video_CodecID, Temp.MediaType);
 
+                Fill(Stream_Video, StreamPos_Last, Video_ID, StreamID, 10, true);
+                Fill(Stream_Video, StreamPos_Last, "Title", Temp.MediaName);
+
                 Ztring LawRating=Temp.Parsers[0]->Retrieve(Stream_General, 0, General_LawRating);
                 if (!LawRating.empty())
                     Fill(Stream_General, 0, General_LawRating, LawRating, true);
-
-                Fill(Stream_Video, StreamPos_Last, Video_ID, StreamID, 10, true);
-                Fill(Stream_Video, StreamPos_Last, "Title", Temp.MediaName);
+                Ztring Title=Temp.Parsers[0]->Retrieve(Stream_General, 0, General_Title);
+                if (!Title.empty() && Retrieve(Stream_General, 0, General_Title).empty())
+                    Fill(Stream_General, 0, General_Title, Title);
 
                 //Special cases
                 if (Temp.Parsers[0]->Count_Get(Stream_Text))
@@ -549,6 +552,9 @@ void File_Gxf::Streams_Finish_PerStream(size_t StreamID, stream &Temp)
                 Ztring LawRating=Temp.Parsers[0]->Retrieve(Stream_General, 0, General_LawRating);
                 if (!LawRating.empty())
                     Fill(Stream_General, 0, General_LawRating, LawRating, true);
+                Ztring Title=Temp.Parsers[0]->Retrieve(Stream_General, 0, General_Title);
+                if (!Title.empty() && Retrieve(Stream_General, 0, General_Title).empty())
+                    Fill(Stream_General, 0, General_Title, Title);
 
                 StreamKind_Last=Stream_Max;
                 StreamPos_Last=(size_t)-1;
@@ -1061,7 +1067,7 @@ void File_Gxf::map()
                         case 13 :
                         case 14 :
                         case 15 :
-                        case 16 :   
+                        case 16 :
                         case 25 :   // was found for DVCPro HD in some files (not in SMPTE ST 360-2009, maybe it is present in a later version)
                                     //DV
                                     {
