@@ -34,6 +34,9 @@
     #include "MediaInfo/MediaInfo_Events_Internal.h"
     #include "MediaInfo/MediaInfo_Config_PerPackage.h"
 #endif //MEDIAINFO_EVENTS
+#if MEDIAINFO_AES
+    #include "base64.h"
+#endif //MEDIAINFO_AES
 using namespace std;
 //---------------------------------------------------------------------------
 
@@ -269,12 +272,15 @@ void File__ReferenceFilesHelper::ParseReferences()
     {
         #if MEDIAINFO_FILTER
             if (MI->Config->File_Filter_Audio_Get())
+            {
                 for (size_t Pos=0; Pos<References.size(); Pos++)
                     if (References[Pos].StreamKind!=Stream_Audio)
                     {
                         References.erase(References.begin()+Pos);
                         Pos--;
                     }
+                CountOfReferencesToParse=References.size();
+            }
         #endif //MEDIAINFO_FILTER
 
         //Filling Filenames from the more complete version and Edit rates
@@ -526,7 +532,7 @@ void File__ReferenceFilesHelper::ParseReferences()
                 }
             }
             Reference->Source=Reference->FileNames.Read(0);
-            if (Reference->StreamKind!=Stream_Max)
+            if (Reference->StreamKind!=Stream_Max && !Reference->Source.empty())
             {
                 if (Reference->StreamPos==(size_t)-1)
                     Reference->StreamPos=Stream_Prepare(Reference->StreamKind);
@@ -545,9 +551,8 @@ void File__ReferenceFilesHelper::ParseReferences()
                 Reference->FileNames=AbsoluteNames;
             else
             {
-                Reference->FileNames.clear();
                 Reference->Status.set(File__Analyze::IsFinished);
-                if (Reference->StreamKind!=Stream_Max)
+                if (Reference->StreamKind!=Stream_Max && !Reference->Source.empty())
                 {
                     MI->Fill(Reference->StreamKind, Reference->StreamPos, "Source_Info", "Missing");
                     if (MI->Retrieve(Reference->StreamKind, Reference->StreamPos, General_ID).empty() && Reference->StreamID!=(int64u)-1)
@@ -617,6 +622,7 @@ void File__ReferenceFilesHelper::ParseReferences()
                         References.erase(References.begin()+Pos);
                         Pos--;
                     }
+                CountOfReferencesToParse=References.size();
                 if (References.empty())
                     return;
 
@@ -632,6 +638,7 @@ void File__ReferenceFilesHelper::ParseReferences()
 
         FileSize_Compute();
         Reference=References.begin();
+        CountOfReferences_ForReadSize=References.size();
         Init_Done=true;
 
         #if MEDIAINFO_DEMUX && MEDIAINFO_NEXTPACKET
@@ -733,6 +740,10 @@ void File__ReferenceFilesHelper::ParseReferences()
         MI->Fill(Stream_General, 0, General_FileSize, MI->Config->File_Size, 10, true);
         MI->Fill(Stream_General, 0, General_StreamSize, MI->File_Size, 10, true);
     }
+    #if MEDIAINFO_ADVANCED
+        if (Config->File_IgnoreSequenceFileSize_Get())
+            MI->Clear(Stream_General, 0, General_FileSize);
+    #endif //MEDIAINFO_ADVANCED
 }
 
 //---------------------------------------------------------------------------
@@ -831,6 +842,8 @@ bool File__ReferenceFilesHelper::ParseReference_Init()
         #endif //MEDIAINFO_EVENTS
         if (!Reference->MI->Open(Reference->FileNames.Read()))
         {
+            if (Reference->StreamKind!=Stream_Max)
+                MI->Fill(Reference->StreamKind, Reference->StreamPos, "Source_Info", "Missing");
             if (!Config->File_KeepInfo_Get())
             {
                 #if MEDIAINFO_DEMUX
@@ -842,7 +855,6 @@ bool File__ReferenceFilesHelper::ParseReference_Init()
                 Reference->FileSize=Reference->MI->Config.File_Size;
                 delete Reference->MI; Reference->MI=NULL;
             }
-            Reference->FileNames.clear();
             Reference->Status.set(File__Analyze::IsFinished);
         }
 
@@ -897,6 +909,17 @@ void File__ReferenceFilesHelper::ParseReference()
                     {
                         while ((Reference->Status=Reference->MI->Open_NextPacket())[8])
                         {
+                                if (!Reference->FileSize_IsPresent && Reference->MI->Config.File_Size!=(int64u)-1)
+                                {
+                                    Reference->FileSize_IsPresent=true;
+                                    if (CountOfReferences_ForReadSize)
+                                    {
+                                        CountOfReferences_ForReadSize--;
+                                        if (!CountOfReferences_ForReadSize)
+                                            CountOfReferences_ForReadSize_Run();
+                                    }
+                                }
+
                                 if (Config->Event_CallBackFunction_IsSet())
                                 {
                                     Config->Demux_EventWasSent=true;
@@ -904,6 +927,8 @@ void File__ReferenceFilesHelper::ParseReference()
                                 }
                         }
                         Reference->CompleteDuration_Pos++;
+                        if (Reference->CompleteDuration_Pos<Reference->CompleteDuration.size() && Reference->CompleteDuration[Reference->CompleteDuration_Pos].MI)
+                            Reference->CompleteDuration[Reference->CompleteDuration_Pos].MI->Open_Buffer_Seek(0, 0, (int64u)-1);
                     }
 
                     #if MEDIAINFO_NEXTPACKET && MEDIAINFO_DEMUX
@@ -915,6 +940,17 @@ void File__ReferenceFilesHelper::ParseReference()
                     {
                         while ((Reference->Status=Reference->CompleteDuration[Reference->CompleteDuration_Pos].MI->Open_NextPacket())[8])
                         {
+                                if (!Reference->FileSize_IsPresent && Reference->MI->Config.File_Size!=(int64u)-1)
+                                {
+                                    Reference->FileSize_IsPresent=true;
+                                    if (CountOfReferences_ForReadSize)
+                                    {
+                                        CountOfReferences_ForReadSize--;
+                                        if (!CountOfReferences_ForReadSize)
+                                            CountOfReferences_ForReadSize_Run();
+                                    }
+                                }
+
                                 if (Config->Event_CallBackFunction_IsSet())
                                 {
                                     Config->Demux_EventWasSent=true;
@@ -922,6 +958,8 @@ void File__ReferenceFilesHelper::ParseReference()
                                 }
                         }
                         Reference->CompleteDuration_Pos++;
+                        if (Reference->CompleteDuration_Pos<Reference->CompleteDuration.size() && Reference->CompleteDuration[Reference->CompleteDuration_Pos].MI)
+                            Reference->CompleteDuration[Reference->CompleteDuration_Pos].MI->Open_Buffer_Seek(0, 0, (int64u)-1);
                     }
                 if (CountOfReferencesToParse)
                     CountOfReferencesToParse--;
@@ -1106,7 +1144,7 @@ void File__ReferenceFilesHelper::ParseReference_Finalize_PerStream ()
             MI->Fill(StreamKind_Last, StreamPos_To, MI->Fill_Parameter(StreamKind_Last, Generic_StreamSize), StreamSize_Temp, 10, true);
         if (FileSize_Temp!=(int64u)-1)
             Reference->FileSize=FileSize_Temp;
-        if (BitRate_Before)
+        if (BitRate_Before && Duration_Temp)
         {
             float64 BitRate_After=((float64)StreamSize_Temp)*8000/Duration_Temp;
             if (BitRate_Before>BitRate_After*0.999 && BitRate_Before<BitRate_After*1.001)
@@ -1322,6 +1360,14 @@ MediaInfo_Internal* File__ReferenceFilesHelper::MI_Create()
     MI_Temp->Option(__T("File_DvDif_DisableAudioIfIsInContainer"), Config->File_DvDif_DisableAudioIfIsInContainer_Get()?__T("1"):__T("0"));
     if ((References.size()>1 || Config->File_MpegTs_ForceMenu_Get()) && !Reference->IsMain && !HasMainFile)
         MI_Temp->Option(__T("File_MpegTs_ForceMenu"), __T("1"));
+    #if MEDIAINFO_AES
+        MI_Temp->Option(__T("File_Encryption_Format"), MI->Retrieve(Stream_General, 0, "Encryption_Format"));
+        MI_Temp->Option(__T("File_Encryption_Key"), Ztring().From_UTF8(Base64::encode(MI->Config->Encryption_Key_Get())));
+        MI_Temp->Option(__T("File_Encryption_Method"), MI->Retrieve(Stream_General, 0, "Encryption_Method"));
+        MI_Temp->Option(__T("File_Encryption_Mode"), MI->Retrieve(Stream_General, 0, "Encryption_Mode"));
+        MI_Temp->Option(__T("File_Encryption_Padding"), MI->Retrieve(Stream_General, 0, "Encryption_Padding"));
+        MI_Temp->Option(__T("File_Encryption_InitializationVector"), MI->Retrieve(Stream_General, 0, "Encryption_InitializationVector"));
+    #endif //AES
     #if MEDIAINFO_NEXTPACKET
         if (Config->NextPacket_Get())
             MI_Temp->Option(__T("File_NextPacket"), __T("1"));
@@ -1383,6 +1429,10 @@ MediaInfo_Internal* File__ReferenceFilesHelper::MI_Create()
     #if MEDIAINFO_DEMUX
         if (Config->Demux_Unpacketize_Get())
             MI_Temp->Option(__T("File_Demux_Unpacketize"), __T("1"));
+        if (Config->Demux_Avc_Transcode_Iso14496_15_to_Iso14496_10_Get())
+            MI_Temp->Option(__T("File_Demux_Avc_Transcode_Iso14496_15_to_Iso14496_10"), __T("1"));
+        if (Config->Demux_Hevc_Transcode_Iso14496_15_to_AnnexB_Get())
+            MI_Temp->Option(__T("File_Demux_Hevc_Transcode_Iso14496_15_to_AnnexB"), __T("1"));
         if (FrameRate)
             MI_Temp->Option(__T("File_Demux_Rate"), Ztring::ToZtring(FrameRate, 25));
         switch (Config->Demux_InitData_Get())
@@ -1465,18 +1515,18 @@ size_t File__ReferenceFilesHelper::Read_Buffer_Seek (size_t Method, int64u Value
                             DurationF/=MI->Config->File_Size;
                             size_t DurationM=(size_t)(DurationF*1000);
                             Ztring DurationS;
-                            DurationS+=L'0'+(wchar_t)(DurationM/(10*60*60*1000)); DurationM%=10*60*60*1000;
-                            DurationS+=L'0'+(wchar_t)(DurationM/(   60*60*1000)); DurationM%=   60*60*1000;
+                            DurationS+=L'0'+(Char)(DurationM/(10*60*60*1000)); DurationM%=10*60*60*1000;
+                            DurationS+=L'0'+(Char)(DurationM/(   60*60*1000)); DurationM%=   60*60*1000;
                             DurationS+=L':';
-                            DurationS+=L'0'+(wchar_t)(DurationM/(   10*60*1000)); DurationM%=   10*60*1000;
-                            DurationS+=L'0'+(wchar_t)(DurationM/(      60*1000)); DurationM%=      60*1000;
+                            DurationS+=L'0'+(Char)(DurationM/(   10*60*1000)); DurationM%=   10*60*1000;
+                            DurationS+=L'0'+(Char)(DurationM/(      60*1000)); DurationM%=      60*1000;
                             DurationS+=L':';
-                            DurationS+=L'0'+(wchar_t)(DurationM/(      10*1000)); DurationM%=      10*1000;
-                            DurationS+=L'0'+(wchar_t)(DurationM/(         1000)); DurationM%=         1000;
+                            DurationS+=L'0'+(Char)(DurationM/(      10*1000)); DurationM%=      10*1000;
+                            DurationS+=L'0'+(Char)(DurationM/(         1000)); DurationM%=         1000;
                             DurationS+=L'.';
-                            DurationS+=L'0'+(wchar_t)(DurationM/(          100)); DurationM%=          100;
-                            DurationS+=L'0'+(wchar_t)(DurationM/(           10)); DurationM%=           10;
-                            DurationS+=L'0'+(wchar_t)(DurationM);
+                            DurationS+=L'0'+(Char)(DurationM/(          100)); DurationM%=          100;
+                            DurationS+=L'0'+(Char)(DurationM/(           10)); DurationM%=           10;
+                            DurationS+=L'0'+(Char)(DurationM);
 
                             CountOfReferencesToParse=References.size();
                             bool HasProblem=false;
@@ -1485,7 +1535,7 @@ size_t File__ReferenceFilesHelper::Read_Buffer_Seek (size_t Method, int64u Value
                                 if (Reference->MI)
                                 {
                                     Ztring Result;
-                                    if (Reference->CompleteDuration.empty() || DurationM<Reference->CompleteDuration[1].Demux_Offset_DTS)
+                                    if (Reference->CompleteDuration.size()<=1 || DurationM<Reference->CompleteDuration[1].Demux_Offset_DTS)
                                     {
                                         Reference->CompleteDuration_Pos=0;
                                         Result=Reference->MI->Option(__T("File_Seek"), DurationS);
@@ -1540,18 +1590,18 @@ size_t File__ReferenceFilesHelper::Read_Buffer_Seek (size_t Method, int64u Value
                         {
                             Duration*=Value;
                             Duration/=10000;
-                            DurationS+=L'0'+(wchar_t)(Duration/(10*60*60*1000)); Duration%=10*60*60*1000;
-                            DurationS+=L'0'+(wchar_t)(Duration/(   60*60*1000)); Duration%=   60*60*1000;
+                            DurationS+=L'0'+(Char)(Duration/(10*60*60*1000)); Duration%=10*60*60*1000;
+                            DurationS+=L'0'+(Char)(Duration/(   60*60*1000)); Duration%=   60*60*1000;
                             DurationS+=L':';
-                            DurationS+=L'0'+(wchar_t)(Duration/(   10*60*1000)); Duration%=   10*60*1000;
-                            DurationS+=L'0'+(wchar_t)(Duration/(      60*1000)); Duration%=      60*1000;
+                            DurationS+=L'0'+(Char)(Duration/(   10*60*1000)); Duration%=   10*60*1000;
+                            DurationS+=L'0'+(Char)(Duration/(      60*1000)); Duration%=      60*1000;
                             DurationS+=L':';
-                            DurationS+=L'0'+(wchar_t)(Duration/(      10*1000)); Duration%=      10*1000;
-                            DurationS+=L'0'+(wchar_t)(Duration/(         1000)); Duration%=         1000;
+                            DurationS+=L'0'+(Char)(Duration/(      10*1000)); Duration%=      10*1000;
+                            DurationS+=L'0'+(Char)(Duration/(         1000)); Duration%=         1000;
                             DurationS+=L'.';
-                            DurationS+=L'0'+(wchar_t)(Duration/(          100)); Duration%=          100;
-                            DurationS+=L'0'+(wchar_t)(Duration/(           10)); Duration%=           10;
-                            DurationS+=L'0'+(wchar_t)(Duration);
+                            DurationS+=L'0'+(Char)(Duration/(          100)); Duration%=          100;
+                            DurationS+=L'0'+(Char)(Duration/(           10)); Duration%=           10;
+                            DurationS+=L'0'+(Char)(Duration);
                         }
                         else
                             DurationS=Ztring::ToZtring(((float64)Value)/100)+__T('%');
@@ -1730,6 +1780,27 @@ void File__ReferenceFilesHelper::FileSize_Compute ()
     }
 }
 
+//---------------------------------------------------------------------------
+void File__ReferenceFilesHelper::CountOfReferences_ForReadSize_Run ()
+{
+    //Computing read buffer size
+    int64u  File_Size_Total=0;
+    int64u  Buffer_Read_Size_Total=MI->Config->File_Buffer_Read_Size_Get();
+    for (references::iterator Reference_Temp=References.begin(); Reference_Temp!=References.end(); ++Reference_Temp)
+        if (Reference_Temp->MI && Reference_Temp->MI->Config.File_Size!=(int64u)-1)
+            File_Size_Total+=Reference_Temp->MI->Config.File_Size;
+    if (File_Size_Total)
+        for (references::iterator Reference_Temp=References.begin(); Reference_Temp!=References.end(); ++Reference_Temp)
+            if (Reference_Temp->MI)
+            {
+                int64u  Buffer_Read_Size_Temp=float64_int64s(((float64)Reference_Temp->MI->Config.File_Size)/File_Size_Total*Buffer_Read_Size_Total);
+                int64u  Buffer_Read_Size=1;
+                while (Buffer_Read_Size<Buffer_Read_Size_Temp)
+                    Buffer_Read_Size<<=1;
+                Reference_Temp->MI->Config.File_Buffer_Read_Size_Set((size_t)Buffer_Read_Size);
+            }
+}
+
 //---------------------------------------------------------------------------
 #if MEDIAINFO_EVENTS
 void File__ReferenceFilesHelper::SubFile_Start()
