@@ -647,9 +647,15 @@ bool File_Mpeg4v::Demux_UnpacketizeContainer_Test()
 
         if (!Status[IsAccepted])
         {
-            Accept("MPEG-4 Visual");
             if (Config->Demux_EventWasSent)
                 return false;
+            File_Mpeg4v* MI=new File_Mpeg4v;
+            Open_Buffer_Init(MI);
+            Open_Buffer_Continue(MI, Buffer, Buffer_Size);
+            bool IsOk=MI->Status[IsAccepted];
+            delete MI;
+            if (!IsOk)
+                return false;
         }
 
         Demux_UnpacketizeContainer_Demux(Buffer[Buffer_Offset+3]==0xB0);
@@ -934,7 +940,7 @@ void File_Mpeg4v::video_object_layer_start()
             if (sprite_enable!=2) //No GMC
                 Skip_SB(                                        "low_latency_sprite_enable");
         }
-        if (video_object_layer_verid==1 && shape!=0) //Shape!=Rectangular
+        if (video_object_layer_verid!=1 && shape!=0) //Shape!=Rectangular
             Skip_SB(                                            "sadct_disable");
         TEST_SB_SKIP(                                           "bits_per_pixel_not_8_bit");
             Skip_S1(4,                                          "quant_precision");
