@@ -1,21 +1,8 @@
-// File_Vp8 - Info for MPEG Video files
-// Copyright (C) 2004-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
 
 //---------------------------------------------------------------------------
 // Pre-compilation
@@ -35,6 +22,7 @@
 
 //---------------------------------------------------------------------------
 #include "MediaInfo/Video/File_Vp8.h"
+#include "MediaInfo/MediaInfo_Config_MediaInfo.h"
 #include "ZenLib/BitStream.h"
 //---------------------------------------------------------------------------
 
@@ -56,7 +44,7 @@ File_Vp8::File_Vp8()
     IsRawStream=true;
 
     //In
-    Frame_Count_Valid=Config_ParseSpeed>=0.3?32:4;
+    Frame_Count_Valid=MediaInfoLib::Config.ParseSpeed_Get()>=0.3?32:4;
 }
 
 //---------------------------------------------------------------------------
@@ -105,7 +93,7 @@ void File_Vp8::Read_Buffer_Continue()
     Get_TB (    frame_type,                                     "frame type");
     Skip_T1( 3,                                                 "version number");
     Skip_TB(                                                    "show_frame flag");
-    Skip_T3(19,                                                 "size of the first data partition");
+    Skip_T4(19,                                                 "size of the first data partition");
     BS_End();
 
     if (!frame_type) //I-Frame
