@@ -1,33 +1,20 @@
-## MediaInfoDLL - All info about media files, for DLL
-#  Copyright (C) 2007-2009 Jerome Martinez, Zen@MediaArea.net
-#
-#  This library is free software: you can redistribute it and/or modify it
-#  under the terms of the GNU Lesser General Public License as published by
-#  the Free Software Foundation, either version 3 of the License, or
-#  any later version.
-#
-#  This library is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU Lesser General Public License for more details.
-#
-#  You should have received a copy of the GNU Lesser General Public License
-#  along with this library. If not, see <http://www.gnu.org/licenses/>.
-#
-# +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+## Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ #
+ # Use of this source code is governed by a BSD-style license that can
+ # be found in the License.html file in the root of the source tree.
+ ##
+
 # +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 #
 #  Public DLL interface implementation
 #  Wrapper for MediaInfo Library
 #  Please see MediaInfo.h for help
 #
-# +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
-#
 # Converted to python module by Petr Kaderabek
 # Modifications by Jerome Martinez
 # Python 3 update by Jerome Martinez
 #
-
+# +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
 
 import os
 from ctypes import *
@@ -51,7 +38,7 @@ else:
 
 
 class Stream:
-    General, Video, Audio, Text, Chapters, Image, Menu, Max = list(range(8))
+    General, Video, Audio, Text, Other, Image, Menu, Max = list(range(8))
 
 class Info:
     Name, Text, Measure, Options, Name_Text, Measure_Text, Info, HowTo, Max = list(range(9))
@@ -203,17 +190,17 @@ class MediaInfo:
     #General information
     def Inform(self):
         if MustUseAnsi:
-            return str(self.MediaInfoA_Inform(self.Handle, 0), "utf_8")
+            return str(self.MediaInfoA_Inform(self.Handle, 0), "utf_8", 'ignore')
         else:
             return self.MediaInfo_Inform(self.Handle, 0)
     def Get(self, StreamKind, StreamNumber, Parameter, InfoKind=Info.Text, SearchKind=Info.Name):
         if MustUseAnsi:
-            return str(self.MediaInfoA_Get(self.Handle, StreamKind, StreamNumber, Parameter.encode("utf-8"), InfoKind, SearchKind), "utf_8")
+            return str(self.MediaInfoA_Get(self.Handle, StreamKind, StreamNumber, Parameter.encode("utf-8"), InfoKind, SearchKind), "utf_8", 'ignore')
         else:
             return self.MediaInfo_Get(self.Handle, StreamKind, StreamNumber, Parameter, InfoKind, SearchKind)
     def GetI(self, StreamKind, StreamNumber, Parameter, InfoKind=Info.Text):
         if MustUseAnsi:
-            return str(self.MediaInfoA_GetI(self.Handle, StreamKind, StreamNumber, Parameter, InfoKind), "utf_8")
+            return str(self.MediaInfoA_GetI(self.Handle, StreamKind, StreamNumber, Parameter, InfoKind), "utf_8", 'ignore')
         else:
             return self.MediaInfo_GetI(self.Handle, StreamKind, StreamNumber, Parameter, InfoKind)
     def Set(self, ToSet, StreamKind, StreamNumber, Parameter, OldParameter=""):
@@ -230,12 +217,12 @@ class MediaInfo:
     #Options
     def Option(self, Option, Value=""):
         if MustUseAnsi:
-            return str(self.MediaInfoA_Option(self.Handle, Option.encode("utf-8"), Value.encode("utf-8")), "utf_8")
+            return str(self.MediaInfoA_Option(self.Handle, Option.encode("utf-8"), Value.encode("utf-8")), "utf_8", 'ignore')
         else:
             return self.MediaInfo_Option(self.Handle, Option, Value)
     def Option_Static(self, Option, Value=""):
         if MustUseAnsi:
-            return str(self.MediaInfoA_Option(None, Option.encode("utf-8"), Value.encode("utf-8")), "utf_8")
+            return str(self.MediaInfoA_Option(None, Option.encode("utf-8"), Value.encode("utf-8")), "utf_8", 'ignore')
         else:
             return self.MediaInfo_Option(None, Option, Value)
     def State_Get(self):
@@ -378,4 +365,3 @@ class MediaInfoList:
         return MediaInfoList_Count_Get (self.Handle, FilePos, StreamKind, StreamNumber=-1)
     def Count_Get_Files(self):
         return MediaInfoList_Count_Get_Files (self.Handle)
-
